cytobands: Cytoband location information
Description
This data set contains cytoband information for a range of species,
taken directly from the UCSC genome annotation database. This data set
is designed to be easily extendable to cover new species.
Format
A list of data frames, one per species, each with one row per
cytoband and the following columns:
- chrThe chromosome number for the cytoband, prefixed with 'chr'.
- startThe start coordinate for the cytoband.
- endThe end coordinate for the cytoband.
- bandThe cytoband number (i.e., the '23.3' in '1q23.3').
- stainThe cytoband stain (see the
stains data set).
- armThe chromosome arm for the cytoband (i.e., the 'q' in '1q23.3').
The list names (i.e. names(cytobands)) should correspond to
species names in the AnnotationDbi packages used. Source
The UCSC genome annotation database: http://hgdownload.cse.ucsc.edu/downloads.html